# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-09 05:36
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0013_preusercontract_finish_at'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='preuserfee',
            options={'ordering': ['-paid_at', '-created_at'], 'permissions': (('add_crm_preuser_fee', '\u53ef\u4ee5\u6dfb\u52a0\u7528\u6237\u7f34\u8d39'), ('view_crm_preuser_fee', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u7f34\u8d39'), ('can_check_crm_preuser_fee', '\u53ef\u4ee5\u5ba1\u6838\u7528\u6237\u7f34\u8d39'), ('can_after_checked_fee', '\u5ba1\u6838\u7f34\u8d39\u540e\u53ef\u4ee5\u540e\u7eed\u64cd\u4f5c'))},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-06 08:47
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0022_auto_20190422_1925'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='regcode',
            options={'ordering': ['-pk'], 'permissions': (('can_ckeck_code', '\u53ef\u4ee5\u9a8c\u8bc1\u5361\u5bc6'), ('can_get_code', '\u53ef\u4ee5\u83b7\u53d6\u5361\u5bc6'))},
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-

__author__ = 'bee'
import pytz, os, json, qrcode
import unicodecsv as csv
from django.http import HttpResponse
from django.conf import settings
from bee_django_crm.models import PreUser, PreUserTrack, PreUserContract, PreUserFee
from datetime import datetime
from distutils.sysconfig import get_python_lib
from django.http import StreamingHttpResponse
from PIL import Image, ImageFont, ImageDraw
from django.apps import apps
from django.contrib.auth import get_user_model
from django.shortcuts import reverse

from .models import get_user_name_field

LOCAL_TIMEZONE = pytz.timezone('Asia/Shanghai')
User = get_user_model()


# 获取转介人姓名
def get_referral_user_name_with_preuser(preuser_id):
    try:
        preuser = PreUser.objects.get(pk=preuser_id)
        referral_user = preuser.referral_user
        if referral_user:
            return get_user_name(referral_user)
        return None
    except Exception as e:
        return None


# 获取转介人姓名
def get_referral_user_name_with_user(user_id):
    try:
        referral_user = User.objects.get(pk=user_id)
        if referral_user:
            return get_user_name(referral_user)
        return None
    except Exception as e:
        return None


# 获取来源id
def get_preuser_source(preuser_id):
    try:
        user = PreUser.objects.get(id=preuser_id)
        return user.source
    except Exception as e:
        return None


# 获取自定义user的自定义name
def get_user_name(user):
    try:
        return getattr(user, get_user_name_field())
    except:
        return None


# 获取联络list
def get_track_list(preuser_id):
    if not preuser_id:
        return None
    track_list = PreUserTrack.objects.filter(user__id=preuser_id)
    return track_list


# 获取缴合同list
def get_contract_list(preuser_id):
    if not preuser_id:
        return None
    track_list = PreUserContract.objects.filter(preuser__id=preuser_id)
    return track_list


# 获取缴费list
def get_fee_list(preuser_id):
    if not preuser_id:
        return None
    fee_list = PreUserFee.objects.filter(preuser__id=preuser_id)
    return fee_list


# 获取本地当前时间
def get_now(tz=LOCAL_TIMEZONE):
    return datetime.now(tz)


# 时区转换
# curtime 为带时区时间
def change_tz(_datetime, tz):
    # return tz.localize(curtime)
    if not _datetime:
        return None
    return _datetime.astimezone(tz=tz)


# 读取json文件
def loadJson(filename):
    file_path = os.path.join(os.getcwd(), 'bee_django_crm', 'static', 'data', filename + ".json")
    if not os.path.exists(file_path):
        file_path = os.path.join(get_python_lib(), 'bee_django_crm', 'static', 'bee_django_crm', 'data',
                                 filename + ".json")
        if not os.path.exists(file_path):
            return None
    f = open(file_path, "r")
    json_data = json.load(f)
    return json_data


class JSONResponse(HttpResponse):
    def __init__(self, obj):
        if isinstance(obj, dict):
            _json_str = json.dumps(obj)
        else:
            _json_str = obj
        super(JSONResponse, self).__init__(_json_str, content_type="application/json;charset=utf-8")


# 导出csv
def export_csv(filename, headers, rows):
    response = StreamingHttpResponse((row for row in csv_itertor(headers, rows)), content_type="text/csv;charset=utf-8")
    response['Content-Disposition'] = 'attachment;filename="' + filename + '.csv"'
    return response


def csv_itertor(headers, rows):
    pseudo_buffer = Echo()
    writer = csv.writer(pseudo_buffer)
    yield writer.writerow(headers)
    for column in rows:
        yield writer.writerow(column)


class Echo(object):
    """An object that implements just the write method of the file-like
    interface.
    """

    def write(self, value):
        """Write the value by returning it, instead of storing in a buffer."""
        return value


# 完
# 制作二维码
def create_qrcode(url="", color="#000000"):
    image = qrcode.make(url)
    image = image.convert("RGBA")
    datas = image.getdata()
    newData = []
    # print(color)
    color = toRgb(color)
    # print(color)
    for item in datas:
        if item[0] == 0 and item[1] == 0 and item[2] == 0:
            item = color
            newData.append(item)
        else:
            newData.append(item)
    image.putdata(newData)
    return image


# 合并二维码，生成带用户名和二维码的转介图片
# 返回image对象
def merge_img(referral_base_path, qrcode_img, qrcode_pos, qrcode_size):
    if not referral_base_path:
        return 1, u'没有图片', None

    try:
        referral_img = Image.open(referral_base_path)
        qrcode_img = qrcode_img.resize(qrcode_size, Image.ANTIALIAS)
        referral_img.paste(qrcode_img, qrcode_pos)

    except Exception as e:
        return 1, str(e), None
    return 0, '', referral_img


def toRgb(qrcode_color):
    import re
    qrcode_color = qrcode_color.replace('#', '')
    opt = re.findall(r'(.{2})', qrcode_color)  # 将字符串两两分割
    color_tuple = ()  # 用以存放最后结果
    for i in range(0, len(opt)):  # for循环，遍历分割后的字符串列表
        t = (int(opt[i], 16),)
        color_tuple += t  # 将结果拼接成12，12，12格式
    # print("转换后的RGB数值为：")
    color_tuple += (255,)
    return color_tuple


# def get_user_model():
#     if settings.CRM_USER_TABLE in ["", None]:
#         user_model = User
#     else:
#         app_name = settings.CRM_USER_TABLE.split(".")[0]
#         model_name = settings.CRM_USER_TABLE.split(".")[1]
#         app = apps.get_app_config(app_name)
#         user_model = app.get_model(model_name)
#     return user_model


def get_landing_url_list():
    url = settings.CRM_LANDING_URL
    url_list = []
    if isinstance(url, list):
        if len(url) == 0:
            return None
        for u in url:
            if not u in ["", None]:
                url_list.append(u)
        if len(url_list) == 0:
            return None
        else:
            return url_list
    else:
        if url in ["", None]:
            return None
        else:
            url_list.append(url)
            return url_list


# 获取审核的后续操作的url
# 如果没有后续操作的权限，也返回空

def get_after_check_url(cookie_user, preuser_fee):
    if settings.CRM_AFTER_CHECK in ["", None]:
        return None
    else:
        if not cookie_user.has_perm("bee_django_crm.can_after_checked_fee"):
            return None
    url = reverse("bee_django_crm:preuser_fee_update_after", kwargs={"pk": preuser_fee.id})
    return url



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 07:55
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0020_regcode_reg_number'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='regcode',
            options={'ordering': ['-pk']},
        ),
        migrations.AlterModelTable(
            name='regcode',
            table='bee_django_crm_code',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-23 09:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0008_preuser_pay_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='applicationquestion',
            name='is_required',
            field=models.BooleanField(default=False, verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe5\xbf\x85\xe5\xa1\xab'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-01-10 05:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0014_auto_20181109_1336'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contract',
            name='duration',
            field=models.IntegerField(blank=True, null=True, verbose_name=b'\xe6\x97\xb6\xe9\x95\xbf'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='period',
            field=models.IntegerField(help_text=b'\xe5\xa6\x82\xe4\xb8\xba\xe9\x95\xbf\xe6\x9c\x9f\xef\xbc\x8c\xe5\x88\x99\xe4\xb8\x8d\xe7\x94\xa8\xe5\xa1\xab\xe5\x86\x99\xe6\x97\xb6\xe9\x95\xbf', verbose_name=b'\xe5\x91\xa8\xe6\x9c\x9f'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-23 07:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0006_auto_20180822_1736'),
    ]

    operations = [
        migrations.AlterField(
            model_name='preuserfee',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name=b'\xe5\xa4\x87\xe6\xb3\xa8'),
        ),
        migrations.AlterField(
            model_name='preuserfee',
            name='pay_status',
            field=models.IntegerField(choices=[(1, b'\xe5\x85\xa8\xe6\xac\xbe'), (2, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xa4\xb4\xe6\xac\xbe'), (3, b'\xe5\x88\x86\xe6\x9c\x9f\xe4\xb8\xad'), (4, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xb0\xbe\xe6\xac\xbe')], default=1, verbose_name=b'\xe4\xbb\x98\xe6\xac\xbe\xe6\x96\xb9\xe5\xbc\x8f\xe5\x8f\x8a\xe7\x8a\xb6\xe6\x80\x81'),
        ),
        migrations.AlterField(
            model_name='preuserfee',
            name='study_at',
            field=models.DateTimeField(blank=True, help_text=b'\xe3\x80\x90\xe5\x85\xa8\xe6\xac\xbe\xe3\x80\x91\xe5\x8f\x8a\xe3\x80\x90\xe5\x88\x86\xe6\x9c\x9f\xe5\xa4\xb4\xe6\xac\xbe\xe3\x80\x91\xe6\x97\xb6\xef\xbc\x8c\xe6\xad\xa4\xe5\xad\x97\xe6\xae\xb5\xe5\xbf\x85\xe5\xa1\xab\xe3\x80\x82\xe5\x85\xb6\xe4\xbb\x96\xe4\xbb\x98\xe6\xac\xbe\xe6\x96\xb9\xe5\xbc\x8f\xe5\x8f\xaf\xe4\xb8\x8d\xe5\xa1\xab\xe5\x86\x99', null=True, verbose_name=b'\xe5\xbc\x80\xe8\xaf\xbe\xe6\x97\xa5\xe6\x9c\x9f'),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

import os
from django.core.exceptions import ValidationError


def jpg_validator(value):
    ext = os.path.splitext(value.name)[1]
    if not ext or not ext in [".jpg", ".jpeg"]:
        raise ValidationError(u'格式不正确，只能是jpg或jpeg格式图片')


def poster_image_size_validator(value):
    size = value.size
    max_size = 300*1024
    if size>max_size:
        raise ValidationError(u'图片不能超过300K')
